==> haskell-yesod-static-1.5.3.1-28-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-yesod-static.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-static
version: 1.5.3.1
id: yesod-static-1.5.3.1-9UzduqrG8vgKEoCxWWh2pv
key: yesod-static-1.5.3.1-9UzduqrG8vgKEoCxWWh2pv
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Static file serving subsite for Yesod Web Framework.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-static>
category: Web, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
indefinite: False
exposed-modules:
    Yesod.EmbeddedStatic Yesod.EmbeddedStatic.Css.AbsoluteUrl
    Yesod.EmbeddedStatic.Generators Yesod.EmbeddedStatic.Types
    Yesod.Static
hidden-modules: Yesod.EmbeddedStatic.Internal
                Yesod.EmbeddedStatic.Css.Util
abi: 3bfb26da8c5e4010c71cbdddb72d1e36
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/yesod-static-1.5.3.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/yesod-static-1.5.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.1/yesod-static-1.5.3.1
hs-libraries: HSyesod-static-1.5.3.1-9UzduqrG8vgKEoCxWWh2pv
depends:
    base-4.10.0.0 containers-0.5.10.2
    old-time-1.1.0.3-JBqRS8v7R0IBEIYolASC7h
    yesod-core-1.4.37-H3gq1KrLSiCD4BHWdk8Tpz
    base64-bytestring-1.0.0.1-D9uFxOosRHvGwKtuClA6fm
    byteable-0.1.1-3VfNJqauCum9lD10cS8nmH bytestring-0.10.8.2
    template-haskell-2.12.0.0 directory-1.3.0.2 transformers-0.5.2.0
    wai-app-static-3.1.6.1-2bu0TJ3TPx2LqJpjRjeOQF
    wai-3.2.1.1-CAwNUvFeJDT75Lly8r7SRS
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz
    file-embed-0.0.10.1-22oUm17C4yT5YwW0zZXlor
    http-types-0.9.1-4bB5vMj0wc7H0s2DJoYpPW
    unix-compat-0.4.3.1-EzGzmB3Cz3F9KJc1tD42yp
    conduit-1.2.12.1-675zH3bb85ZA0Qb4jnuu4h
    conduit-extra-1.2.0-DSsj91zKB0UtOeZqteiA7
    cryptonite-conduit-0.2.0-6EivmoI3FRfAM9Vy1xVCvf
    cryptonite-0.24-6xc03vLJCgFIcBUj8mCBYP
    memory-0.14.8-KR3LQmPtL0V2hu8SCUEPxQ
    data-default-0.7.1.1-7D2kYbZAPZs3NL2w6K0r5J
    mime-types-0.1.0.7-3ciIUWEACqtAI9UjjJR1x0
    hjsmin-0.2.0.2-5piZy2NVxbqE2nQQueFQwD filepath-1.4.1.2
    resourcet-1.1.9-L2AvjA6mP5RDwDqcbBVGV9
    unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN process-1.6.1.0
    async-2.1.1.1-2NW8RVpRWiC9M88FM7mCHc
    attoparsec-0.13.2.0-CjTw1SIXl7j4WJB8EsmBPm
    blaze-builder-0.4.0.2-9jN75sESh05JfWRLWr51Wl
    css-text-0.1.2.2-4ZcO2ZYzAYyG3e532VtBN1
    hashable-1.2.6.1-5D85BzUWIsjDNuFvtLMWyk
    exceptions-0.8.3-BkxQoXHQAbWGd28nf3VeZ6
abi-depends: base-4.10.0.0=835a16347ec1b210054efd02671c29ee
             containers-0.5.10.2=dd4e66fa9ac268f47a15786f1100b042
             old-time-1.1.0.3-JBqRS8v7R0IBEIYolASC7h=68a36e33bd2b1b969b7f48a0dec887aa
             yesod-core-1.4.37-H3gq1KrLSiCD4BHWdk8Tpz=667fb6776dc52ecdbdee67226f5677df
             base64-bytestring-1.0.0.1-D9uFxOosRHvGwKtuClA6fm=3f1f6920f093e2e6ae14fb0bb49a0b10
             byteable-0.1.1-3VfNJqauCum9lD10cS8nmH=ecad75526b40e3669fcd751d69f205cf
             bytestring-0.10.8.2=590a7a3c0bdcf7a6a59d8c8ef548a44a
             template-haskell-2.12.0.0=f12600dbe1b363b1dcebe6addb7b269e
             directory-1.3.0.2=3638cd3d85711234b23f0c0ec04058d3
             transformers-0.5.2.0=2645d250dd615ce454f807270041c5ea
             wai-app-static-3.1.6.1-2bu0TJ3TPx2LqJpjRjeOQF=f2543c8623cc2483152b41dc36d28d63
             wai-3.2.1.1-CAwNUvFeJDT75Lly8r7SRS=9c6a864f8fa1a2052bc8fe34ff093e3a
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=9217a19661a41b462c62d1a4bdf2e9b1
             file-embed-0.0.10.1-22oUm17C4yT5YwW0zZXlor=ba99223a63c2e21ef45c374192c1b72c
             http-types-0.9.1-4bB5vMj0wc7H0s2DJoYpPW=b05755a8562dd13d7429852f04c3b73b
             unix-compat-0.4.3.1-EzGzmB3Cz3F9KJc1tD42yp=c3087b497fbb9a1a0b9e1db4ff794ff4
             conduit-1.2.12.1-675zH3bb85ZA0Qb4jnuu4h=6bf0cea2ccec20058d527d53a4f54166
             conduit-extra-1.2.0-DSsj91zKB0UtOeZqteiA7=3a7b6797885b4f7b0c19a45c8992b33f
             cryptonite-conduit-0.2.0-6EivmoI3FRfAM9Vy1xVCvf=4bad23b1d32cca38d95a1071761cb7d0
             cryptonite-0.24-6xc03vLJCgFIcBUj8mCBYP=2aff2c890f2811a4d19d3ee0bfb54087
             memory-0.14.8-KR3LQmPtL0V2hu8SCUEPxQ=95aa1eec1ee6d97d56ce509d22129a9d
             data-default-0.7.1.1-7D2kYbZAPZs3NL2w6K0r5J=f7324150b92035ce2f13f55c36f08ab4
             mime-types-0.1.0.7-3ciIUWEACqtAI9UjjJR1x0=0aeddae0dfd23172e1ac5bc7d4b98380
             hjsmin-0.2.0.2-5piZy2NVxbqE2nQQueFQwD=5d31fc0bece5343e3152591a8572c70e
             filepath-1.4.1.2=7f2f990ae2114c616de6dfc1a7f18a6e
             resourcet-1.1.9-L2AvjA6mP5RDwDqcbBVGV9=5151457a381efe5b858f660d93294781
             unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN=f561664cdb04511e569f0d44c9086d8e
             process-1.6.1.0=d01a8ca2c6610f40dfd0fe25f50afb10
             async-2.1.1.1-2NW8RVpRWiC9M88FM7mCHc=877e0732f418402f16d143a5b45ef88e
             attoparsec-0.13.2.0-CjTw1SIXl7j4WJB8EsmBPm=754c9623208b731856696d360a56d5ab
             blaze-builder-0.4.0.2-9jN75sESh05JfWRLWr51Wl=92c6d3f9634de2495e94b00787c1e242
             css-text-0.1.2.2-4ZcO2ZYzAYyG3e532VtBN1=46a3e6a484d51b6da422bd99044d5500
             hashable-1.2.6.1-5D85BzUWIsjDNuFvtLMWyk=5285d4c9a9fd47aab57774d045fde1ac
             exceptions-0.8.3-BkxQoXHQAbWGd28nf3VeZ6=98ab8c145be258d01b7a6333e00858ed
haddock-interfaces: /usr/share/doc/haskell-yesod-static/html/yesod-static.haddock
haddock-html: /usr/share/doc/haskell-yesod-static/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yesod-static-1.5.3.1-32-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-yesod-static.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-static
version: 1.5.3.1
id: yesod-static-1.5.3.1-w0SZ21tXptFy7G2UWJQfV
key: yesod-static-1.5.3.1-w0SZ21tXptFy7G2UWJQfV
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Static file serving subsite for Yesod Web Framework.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-static>
category: Web, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
indefinite: False
exposed-modules:
    Yesod.EmbeddedStatic Yesod.EmbeddedStatic.Css.AbsoluteUrl
    Yesod.EmbeddedStatic.Generators Yesod.EmbeddedStatic.Types
    Yesod.Static
hidden-modules: Yesod.EmbeddedStatic.Internal
                Yesod.EmbeddedStatic.Css.Util
abi: 56e613af5e0bd84b6b54d12b7cdfe983
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/yesod-static-1.5.3.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/yesod-static-1.5.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.1/yesod-static-1.5.3.1
hs-libraries: HSyesod-static-1.5.3.1-w0SZ21tXptFy7G2UWJQfV
depends:
    base-4.10.0.0 containers-0.5.10.2
    old-time-1.1.0.3-JBqRS8v7R0IBEIYolASC7h
    yesod-core-1.4.37-8at1q0UcqJ6LfszxkbB10K
    base64-bytestring-1.0.0.1-D9uFxOosRHvGwKtuClA6fm
    byteable-0.1.1-3VfNJqauCum9lD10cS8nmH bytestring-0.10.8.2
    template-haskell-2.12.0.0 directory-1.3.0.2 transformers-0.5.2.0
    wai-app-static-3.1.6.1-G8IZbuu2I3uAJbeqF2v4zS
    wai-3.2.1.1-CAwNUvFeJDT75Lly8r7SRS
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz
    file-embed-0.0.10.1-22oUm17C4yT5YwW0zZXlor
    http-types-0.9.1-4bB5vMj0wc7H0s2DJoYpPW
    unix-compat-0.4.3.1-EzGzmB3Cz3F9KJc1tD42yp
    conduit-1.2.12.1-675zH3bb85ZA0Qb4jnuu4h
    conduit-extra-1.2.0-DSsj91zKB0UtOeZqteiA7
    cryptonite-conduit-0.2.2-1VX3x6AYY0C2bmvrVivIXp
    cryptonite-0.24-K7sWwdWlF3ZAyrdpRtdoRO
    memory-0.14.8-BAg3DtPwumR3TQfKUohmeR
    data-default-0.7.1.1-7D2kYbZAPZs3NL2w6K0r5J
    mime-types-0.1.0.7-3ciIUWEACqtAI9UjjJR1x0
    hjsmin-0.2.0.2-5piZy2NVxbqE2nQQueFQwD filepath-1.4.1.2
    resourcet-1.1.9-L2AvjA6mP5RDwDqcbBVGV9
    unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN process-1.6.1.0
    async-2.1.1.1-2NW8RVpRWiC9M88FM7mCHc
    attoparsec-0.13.2.0-CjTw1SIXl7j4WJB8EsmBPm
    blaze-builder-0.4.0.2-9jN75sESh05JfWRLWr51Wl
    css-text-0.1.2.2-4ZcO2ZYzAYyG3e532VtBN1
    hashable-1.2.6.1-5D85BzUWIsjDNuFvtLMWyk
    exceptions-0.8.3-BkxQoXHQAbWGd28nf3VeZ6
abi-depends: base-4.10.0.0=835a16347ec1b210054efd02671c29ee
             containers-0.5.10.2=dd4e66fa9ac268f47a15786f1100b042
             old-time-1.1.0.3-JBqRS8v7R0IBEIYolASC7h=68a36e33bd2b1b969b7f48a0dec887aa
             yesod-core-1.4.37-8at1q0UcqJ6LfszxkbB10K=9717eb91fa58a044e07089bc3cd3174a
             base64-bytestring-1.0.0.1-D9uFxOosRHvGwKtuClA6fm=3f1f6920f093e2e6ae14fb0bb49a0b10
             byteable-0.1.1-3VfNJqauCum9lD10cS8nmH=ecad75526b40e3669fcd751d69f205cf
             bytestring-0.10.8.2=590a7a3c0bdcf7a6a59d8c8ef548a44a
             template-haskell-2.12.0.0=f12600dbe1b363b1dcebe6addb7b269e
             directory-1.3.0.2=3638cd3d85711234b23f0c0ec04058d3
             transformers-0.5.2.0=2645d250dd615ce454f807270041c5ea
             wai-app-static-3.1.6.1-G8IZbuu2I3uAJbeqF2v4zS=36359c37594c94c57d2e05c06826af6d
             wai-3.2.1.1-CAwNUvFeJDT75Lly8r7SRS=9c6a864f8fa1a2052bc8fe34ff093e3a
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=9217a19661a41b462c62d1a4bdf2e9b1
             file-embed-0.0.10.1-22oUm17C4yT5YwW0zZXlor=ba99223a63c2e21ef45c374192c1b72c
             http-types-0.9.1-4bB5vMj0wc7H0s2DJoYpPW=b05755a8562dd13d7429852f04c3b73b
             unix-compat-0.4.3.1-EzGzmB3Cz3F9KJc1tD42yp=c3087b497fbb9a1a0b9e1db4ff794ff4
             conduit-1.2.12.1-675zH3bb85ZA0Qb4jnuu4h=6bf0cea2ccec20058d527d53a4f54166
             conduit-extra-1.2.0-DSsj91zKB0UtOeZqteiA7=3a7b6797885b4f7b0c19a45c8992b33f
             cryptonite-conduit-0.2.2-1VX3x6AYY0C2bmvrVivIXp=405a99d13fe37401763d54ce8bb6c0a1
             cryptonite-0.24-K7sWwdWlF3ZAyrdpRtdoRO=9573bf3c543b458d8ee9733176e7c149
             memory-0.14.8-BAg3DtPwumR3TQfKUohmeR=d910bbee9f7131c0d1070631b55ccda1
             data-default-0.7.1.1-7D2kYbZAPZs3NL2w6K0r5J=f7324150b92035ce2f13f55c36f08ab4
             mime-types-0.1.0.7-3ciIUWEACqtAI9UjjJR1x0=0aeddae0dfd23172e1ac5bc7d4b98380
             hjsmin-0.2.0.2-5piZy2NVxbqE2nQQueFQwD=5d31fc0bece5343e3152591a8572c70e
             filepath-1.4.1.2=7f2f990ae2114c616de6dfc1a7f18a6e
             resourcet-1.1.9-L2AvjA6mP5RDwDqcbBVGV9=5151457a381efe5b858f660d93294781
             unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN=f561664cdb04511e569f0d44c9086d8e
             process-1.6.1.0=d01a8ca2c6610f40dfd0fe25f50afb10
             async-2.1.1.1-2NW8RVpRWiC9M88FM7mCHc=877e0732f418402f16d143a5b45ef88e
             attoparsec-0.13.2.0-CjTw1SIXl7j4WJB8EsmBPm=754c9623208b731856696d360a56d5ab
             blaze-builder-0.4.0.2-9jN75sESh05JfWRLWr51Wl=92c6d3f9634de2495e94b00787c1e242
             css-text-0.1.2.2-4ZcO2ZYzAYyG3e532VtBN1=46a3e6a484d51b6da422bd99044d5500
             hashable-1.2.6.1-5D85BzUWIsjDNuFvtLMWyk=5285d4c9a9fd47aab57774d045fde1ac
             exceptions-0.8.3-BkxQoXHQAbWGd28nf3VeZ6=98ab8c145be258d01b7a6333e00858ed
haddock-interfaces: /usr/share/doc/haskell-yesod-static/html/yesod-static.haddock
haddock-html: /usr/share/doc/haskell-yesod-static/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
